==> haskell-hls-alternate-number-format-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-61AVgX2ZeUY73ogErgvK06

key:
    hls-alternate-number-format-plugin-2.1.0.0-61AVgX2ZeUY73ogErgvK06

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  55f634eb6ad68c8abe4df5a519680b85
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-61AVgX2ZeUY73ogErgvK06

depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-boot-th-9.6.6
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-alternate-number-format-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-G6hahaH9ncm6KPFPEFLteq

key:
    hls-alternate-number-format-plugin-2.1.0.0-G6hahaH9ncm6KPFPEFLteq

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  85d396f6de394e22d8e2fd4b95402979
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-G6hahaH9ncm6KPFPEFLteq

depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb ghc-boot-th-9.6.6
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 regex-tdfa-1.3.2.5-EWGvfiHhNcof6jXGuIJ2K
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
